import VueStore from 'vuetech-foundation/src/Libs/VueStore/VueStore'
import VueRouting from 'vuetech-foundation/src/Libs/VueRouting/VueRouting'

const ScanModules = require('vuetech-foundation/src/Functions/ScanModules')
const InitAxios = require('vuetech-foundation/src/Functions/InitAxios')

class VueBoot {

    constructor() {

        InitAxios()

        this.store = new VueStore()
        this.router = new VueRouting()
    }

    SetComponents(context) {
        ScanModules(context, (key, name, ctx) => Vue.component(name, ctx(key).default))
        return this
    }

    SetMixins(context) {
        ScanModules(context, (key, name, ctx) => Vue.mixin(ctx(key)))
        return this
    }

    SetStores(context) {
        this.store.Add(context)
        return this
    }

    SetRoutes(context) {
        this.router.Add(context)
        return this
    }

    LoadResources(resources) {
        this
            .SetComponents(resources.components)
            .SetMixins(resources.mixins)
            .SetStores(resources.stores)
            .SetRoutes(resources.routes) 
        return this
    }

    CreateObject() {
        return new Vue({
            el: '#vue-app',
            store: this.store.store,
            router: this.router.router,
        })
    }
}

export default new VueBoot()